{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 8,
   "id": "bc077a0d-3cac-4f63-8b00-fa6d878fe2a7",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-cell"
    ]
   },
   "outputs": [],
   "source": [
    "import pandas as pd\n",
    "import altair as alt\n",
    "records_data = pd.read_csv(\"records-sub-stats-all.csv\")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "33e18670-eddb-40e5-9139-1192b55414b7",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "# Records (with sub-collections)\n",
    "\n",
    "(see below for explaination of why some terms are in quotes)\n",
    "\n",
    "This is an attempt to highlight particular \"subcollections\" in institutions, to give more indication of where cataloguing may be more complete in one area than in another. It should be noted it *may be* but is not always an indication of different cataloguing types of records (i.e. museum, library, archive). Even if an institution has examples of all three, that not automatically mean three sub-collections. Equally, an institution might have three sub-collections, but this does not mean it contains a museum, library and archive, it might be for example three different distinct museum collections that make up the overall institution. \n"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "54492bdc-9938-4242-900a-bcedf5cecc21",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "## Collection with subcollections record size by topic and sector"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "id": "8ea4d746-54f9-4c65-9658-697faf1f1fa8",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-input",
     "full-size"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<style>\n",
       "  #altair-viz-84e8ac99a4974e4a9ba20986aaea9ec8.vega-embed {\n",
       "    width: 100%;\n",
       "    display: flex;\n",
       "  }\n",
       "\n",
       "  #altair-viz-84e8ac99a4974e4a9ba20986aaea9ec8.vega-embed details,\n",
       "  #altair-viz-84e8ac99a4974e4a9ba20986aaea9ec8.vega-embed details summary {\n",
       "    position: relative;\n",
       "  }\n",
       "</style>\n",
       "<div id=\"altair-viz-84e8ac99a4974e4a9ba20986aaea9ec8\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-84e8ac99a4974e4a9ba20986aaea9ec8\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-84e8ac99a4974e4a9ba20986aaea9ec8\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.17.0?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"5.17.0\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"numberFormat\": \".2s\"}, \"data\": {\"name\": \"data-0de5e3c2fbd3c950d7cc263b6c870044\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"field\": \"institution\", \"legend\": {\"orient\": \"bottom\", \"titleOrient\": \"left\", \"columns\": 4}, \"type\": \"nominal\"}, \"column\": {\"field\": \"sector\", \"type\": \"nominal\"}, \"tooltip\": [{\"field\": \"institution\", \"type\": \"nominal\"}, {\"field\": \"subcollection\", \"type\": \"nominal\"}, {\"field\": \"record_count\", \"type\": \"quantitative\"}], \"x\": {\"field\": \"record_count\", \"type\": \"quantitative\"}, \"y\": {\"field\": \"topic\", \"type\": \"nominal\"}}, \"resolve\": {\"scale\": {\"x\": \"independent\"}}, \"title\": {\"text\": \"Collection Size (Records) by topic\", \"anchor\": \"middle\"}, \"width\": 220, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.17.0.json\", \"datasets\": {\"data-0de5e3c2fbd3c950d7cc263b6c870044\": [{\"institution\": \"Oxford University\", \"subcollection\": \"History of Science Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 33592}, {\"institution\": \"Oxford University\", \"subcollection\": \"Museum of Natural History\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 505745}, {\"institution\": \"Oxford University\", \"subcollection\": \"Pitt Rivers Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"anthopology\", \"precision\": \"estimate\", \"record_count\": 513107}, {\"institution\": \"University of Cambridge\", \"subcollection\": \"Whipple Museum of the History of Science\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 7148}, {\"institution\": \"Durham University\", \"subcollection\": \"Oriental Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 33234}, {\"institution\": \"University College London\", \"subcollection\": \"Petrie Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 83455}, {\"institution\": \"University College London\", \"subcollection\": \"UCL Art Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 10712}, {\"institution\": \"University College London\", \"subcollection\": \"UCL Pathology Collection\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"record_count\": 8817}, {\"institution\": \"University College London\", \"subcollection\": \"UCL Pathology Collection\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 1462}, {\"institution\": \"Glasgow Woman's Library\", \"subcollection\": \"Museum Collections\", \"sector\": \"library\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 3567}, {\"institution\": \"National Museum of the Royal Navy\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"architecture\", \"precision\": \"estimate\", \"record_count\": 195690}, {\"institution\": \"National Museums Scotland\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"architecture\", \"precision\": \"estimate\", \"record_count\": 820000}, {\"institution\": \"National Waterways Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 4574}, {\"institution\": \"Government Art Collection\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 15247}, {\"institution\": \"People's History Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 5680}, {\"institution\": \"Portable Antiquities Scheme\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1133397}, {\"institution\": \"Royal Air Force Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1344}, {\"institution\": \"Royal Botanic Gardens Kew\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 5700000}, {\"institution\": \"Royal Collection\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 289595}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 57017}, {\"institution\": \"Courtauld Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 33501}, {\"institution\": \"Dulwich Picture Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 33501}, {\"institution\": \"Chatham Historic Dockyard\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1548}, {\"institution\": \"Colchester and Ipswich Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 220000}, {\"institution\": \"London Transport Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 271610}, {\"institution\": \"Food Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 32040}, {\"institution\": \"Watts Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 7756}, {\"institution\": \"Aberdeen Archives, Gallery and Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"record_count\": 151529}, {\"institution\": \"Black Country Living Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"record_count\": 4903}, {\"institution\": \"The Box Plymouth\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"record_count\": 21691}, {\"institution\": \"Colchester and Ipswich Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 220000}, {\"institution\": \"Dundee Heritage Trust\", \"subcollection\": \"Martime\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"record_count\": 2411}, {\"institution\": \"Dundee Heritage Trust\", \"subcollection\": \"Textiles\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"fashion\", \"precision\": \"estimate\", \"record_count\": 5864}, {\"institution\": \"Dundee Heritage Trust\", \"subcollection\": \"Dundee and Social History\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"record_count\": 317}, {\"institution\": \"Poole Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1489}, {\"institution\": \"Potteries Museum and Art Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1489}, {\"institution\": \"Ripon Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 15}, {\"institution\": \"Royal Albert Memorial Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 16000}, {\"institution\": \"Sheffield Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1000}, {\"institution\": \"Tyne & Wear Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 490107}, {\"institution\": \"Wiltshire Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 126410}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Fine Art\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 15733}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Decorative Arts\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 11080}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Archaeology\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"archaeology\", \"precision\": \"estimate\", \"record_count\": 21229}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Biology\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 14282}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Costume and Textiles\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"fashion\", \"precision\": \"estimate\", \"record_count\": 15468}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Geology\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"geology\", \"precision\": \"estimate\", \"record_count\": 34048}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Military History\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 6838}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Photographs\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"record_count\": 5902}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Social History\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"record_count\": 29774}, {\"institution\": \"Victoria & Albert Museum\", \"subcollection\": \"Victoria & Albert Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"exact\", \"record_count\": 1282240}, {\"institution\": \"Museum of the Home\", \"subcollection\": \"Museum of the Home\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"exact\", \"record_count\": 12200}, {\"institution\": \"Horniman Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 132612}, {\"institution\": \"Imperial War Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 1737698}, {\"institution\": \"National Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 2626}, {\"institution\": \"National Museums Liverpool\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 73682}, {\"institution\": \"National Portrait Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 220000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Entomology collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 34000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Botany collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 6000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Zooology collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 29000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Palaeontology collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 7000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Mineralogy collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 500000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Library and archive collections\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 1500000}, {\"institution\": \"Royal Armouries\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 65627}, {\"institution\": \"Sir John Soane's Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 57164}, {\"institution\": \"Tate Gallery Group\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 79236}, {\"institution\": \"British Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 2000000}, {\"institution\": \"Oxford University\", \"subcollection\": \"History of Science Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 21011}, {\"institution\": \"Oxford University\", \"subcollection\": \"Bodleian Library\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"national\", \"precision\": \"estimate\", \"record_count\": 8000000}, {\"institution\": \"Manchester Metropolitan Unversity\", \"subcollection\": \"Special Collections\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 28600}, {\"institution\": \"SOAS, University of London\", \"subcollection\": \"Special Collections\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 40337}, {\"institution\": \"University of Reading\", \"subcollection\": \"Library Collection\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 0}, {\"institution\": \"Lambeth Palace Library\", \"subcollection\": \"Sion College Collections\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"theology\", \"precision\": \"estimate\", \"record_count\": 15000}, {\"institution\": \"National Museum of the Royal Navy\", \"subcollection\": \"Library Collection\", \"sector\": \"national\", \"type\": \"library\", \"topic\": \"architecture\", \"precision\": \"estimate\", \"record_count\": 195690}, {\"institution\": \"Royal Air Force Museum\", \"subcollection\": \"Library Collection\", \"sector\": \"national\", \"type\": \"library\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1344}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"William Salt Library\", \"sector\": \"regional\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 139389}, {\"institution\": \"Chatham Historic Dockyard\", \"subcollection\": \"Library Collection\", \"sector\": \"independent\", \"type\": \"library\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1548}, {\"institution\": \"Watts Gallery\", \"subcollection\": \"Library Collection\", \"sector\": \"regional\", \"type\": \"library\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 7756}, {\"institution\": \"Victoria & Albert Museum\", \"subcollection\": \"National Art Library\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 849000}, {\"institution\": \"Museum of the Home\", \"subcollection\": \"Library Collection\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"history\", \"precision\": \"exact\", \"record_count\": 6290}, {\"institution\": \"Royal Armouries\", \"subcollection\": \"Library Collection\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 65627}, {\"institution\": \"Sir John Soane's Museum\", \"subcollection\": \"Library Collection\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 57164}, {\"institution\": \"University of Cambridge\", \"subcollection\": \"Whipple Museum of the History of Science\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 6979}, {\"institution\": \"Unversity of Warwick\", \"subcollection\": \"Modern Records Centre\", \"sector\": \"university\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"exact\", \"record_count\": 367655}, {\"institution\": \"University of Reading\", \"subcollection\": \"Archive Collection\", \"sector\": \"university\", \"type\": \"archive\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 186216}, {\"institution\": \"National Waterways Museum\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 53195}, {\"institution\": \"Historic England Archive\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Historic Environment\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Royal Air Force Museum\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 88}, {\"institution\": \"Gwynedd Archive Services\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 12000}, {\"institution\": \"Hampshire Archives and Local Studies\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Kresen Kernow\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 614909}, {\"institution\": \"North East Wales Archives\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 338969}, {\"institution\": \"Public Record Office Northern Ireland\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Stoke on Trent City Archives\", \"sector\": \"regional\", \"type\": \"archives\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 44238}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Staffordshire Record Office\", \"sector\": \"regional\", \"type\": \"archives\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 443779}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Stoke on Trent City Archives\", \"sector\": \"regional\", \"type\": \"archives\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 15606}, {\"institution\": \"Tyne & Wear Archives Catalogue\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 4602160}, {\"institution\": \"West Glamorgan Archive Service\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 230000}, {\"institution\": \"Yorkshire Film Archive\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 8483}, {\"institution\": \"Chatham Historic Dockyard\", \"subcollection\": \"Archive Collection\", \"sector\": \"independent\", \"type\": \"archive\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 2058}, {\"institution\": \"Watts Gallery\", \"subcollection\": \"Archive Collection\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 668}, {\"institution\": \"Aberdeen Archives, Gallery and Museums\", \"subcollection\": \"Archive Collection\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"record_count\": 95798}, {\"institution\": \"Bradford District Museums & Galleries\", \"subcollection\": \"Photographic Archive\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 21878}, {\"institution\": \"Ripon Museums\", \"subcollection\": \"Archive Collection\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 5}, {\"institution\": \"St Helens Borough Council\", \"subcollection\": \"Archive Collections\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 93344}, {\"institution\": \"Victoria & Albert Museum\", \"subcollection\": \"Victoria & Albert Museum Archives\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"art\", \"precision\": \"exact\", \"record_count\": 157835}, {\"institution\": \"Royal Armouries\", \"subcollection\": \"Archive Collection\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 130130}, {\"institution\": \"Sir John Soane's Museum\", \"subcollection\": \"Archive Collection\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 0}, {\"institution\": \"Tate Gallery Group\", \"subcollection\": \"Archive Collection\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 807060}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 9,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "title = alt.TitleParams('Collection Size (Artefact Records) by topic', anchor='middle')\n",
    "alt.Chart(records_data,title=title).mark_bar().encode(\n",
    "    alt.Color('institution:N').legend(orient=\"bottom\", titleOrient=\"left\", columns=4),\n",
    "    x='record_count:Q',\n",
    "    tooltip=['institution', 'subcollection', 'record_count'],\n",
    "    y='topic:N',\n",
    "    column='sector'\n",
    ").properties(width=220).resolve_scale(x='independent').configure(numberFormat='.2s')"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "286c439a-acbf-43c9-a1f2-0d271308f28b",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "## Artefact records with subcollections record size by precision"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "id": "618b3c95-25a4-40d4-a49d-7d686f8daea8",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<style>\n",
       "  #altair-viz-89412c1d9adf4cea9632c878c3be2f49.vega-embed {\n",
       "    width: 100%;\n",
       "    display: flex;\n",
       "  }\n",
       "\n",
       "  #altair-viz-89412c1d9adf4cea9632c878c3be2f49.vega-embed details,\n",
       "  #altair-viz-89412c1d9adf4cea9632c878c3be2f49.vega-embed details summary {\n",
       "    position: relative;\n",
       "  }\n",
       "</style>\n",
       "<div id=\"altair-viz-89412c1d9adf4cea9632c878c3be2f49\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-89412c1d9adf4cea9632c878c3be2f49\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-89412c1d9adf4cea9632c878c3be2f49\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.17.0?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"5.17.0\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"numberFormat\": \".2s\"}, \"data\": {\"name\": \"data-0de5e3c2fbd3c950d7cc263b6c870044\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"field\": \"institution\", \"legend\": {\"orient\": \"bottom\", \"titleOrient\": \"left\", \"columns\": 4}, \"sort\": \"descending\", \"type\": \"nominal\"}, \"column\": {\"field\": \"precision\", \"type\": \"ordinal\"}, \"tooltip\": {\"field\": \"subcollection\", \"type\": \"nominal\"}, \"x\": {\"field\": \"record_count\", \"type\": \"quantitative\"}, \"y\": {\"field\": \"topic\", \"type\": \"nominal\"}}, \"resolve\": {\"scale\": {\"x\": \"independent\"}}, \"title\": {\"text\": \"Collection Size (Artefact Records) by precision\", \"anchor\": \"middle\"}, \"width\": 220, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.17.0.json\", \"datasets\": {\"data-0de5e3c2fbd3c950d7cc263b6c870044\": [{\"institution\": \"Oxford University\", \"subcollection\": \"History of Science Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 33592}, {\"institution\": \"Oxford University\", \"subcollection\": \"Museum of Natural History\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 505745}, {\"institution\": \"Oxford University\", \"subcollection\": \"Pitt Rivers Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"anthopology\", \"precision\": \"estimate\", \"record_count\": 513107}, {\"institution\": \"University of Cambridge\", \"subcollection\": \"Whipple Museum of the History of Science\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 7148}, {\"institution\": \"Durham University\", \"subcollection\": \"Oriental Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 33234}, {\"institution\": \"University College London\", \"subcollection\": \"Petrie Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 83455}, {\"institution\": \"University College London\", \"subcollection\": \"UCL Art Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 10712}, {\"institution\": \"University College London\", \"subcollection\": \"UCL Pathology Collection\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"record_count\": 8817}, {\"institution\": \"University College London\", \"subcollection\": \"UCL Pathology Collection\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 1462}, {\"institution\": \"Glasgow Woman's Library\", \"subcollection\": \"Museum Collections\", \"sector\": \"library\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 3567}, {\"institution\": \"National Museum of the Royal Navy\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"architecture\", \"precision\": \"estimate\", \"record_count\": 195690}, {\"institution\": \"National Museums Scotland\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"architecture\", \"precision\": \"estimate\", \"record_count\": 820000}, {\"institution\": \"National Waterways Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 4574}, {\"institution\": \"Government Art Collection\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 15247}, {\"institution\": \"People's History Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 5680}, {\"institution\": \"Portable Antiquities Scheme\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1133397}, {\"institution\": \"Royal Air Force Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1344}, {\"institution\": \"Royal Botanic Gardens Kew\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 5700000}, {\"institution\": \"Royal Collection\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 289595}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 57017}, {\"institution\": \"Courtauld Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 33501}, {\"institution\": \"Dulwich Picture Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 33501}, {\"institution\": \"Chatham Historic Dockyard\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1548}, {\"institution\": \"Colchester and Ipswich Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 220000}, {\"institution\": \"London Transport Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 271610}, {\"institution\": \"Food Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 32040}, {\"institution\": \"Watts Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 7756}, {\"institution\": \"Aberdeen Archives, Gallery and Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"record_count\": 151529}, {\"institution\": \"Black Country Living Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"record_count\": 4903}, {\"institution\": \"The Box Plymouth\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"record_count\": 21691}, {\"institution\": \"Colchester and Ipswich Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 220000}, {\"institution\": \"Dundee Heritage Trust\", \"subcollection\": \"Martime\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"record_count\": 2411}, {\"institution\": \"Dundee Heritage Trust\", \"subcollection\": \"Textiles\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"fashion\", \"precision\": \"estimate\", \"record_count\": 5864}, {\"institution\": \"Dundee Heritage Trust\", \"subcollection\": \"Dundee and Social History\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"record_count\": 317}, {\"institution\": \"Poole Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1489}, {\"institution\": \"Potteries Museum and Art Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1489}, {\"institution\": \"Ripon Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 15}, {\"institution\": \"Royal Albert Memorial Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 16000}, {\"institution\": \"Sheffield Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1000}, {\"institution\": \"Tyne & Wear Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 490107}, {\"institution\": \"Wiltshire Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 126410}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Fine Art\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 15733}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Decorative Arts\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 11080}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Archaeology\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"archaeology\", \"precision\": \"estimate\", \"record_count\": 21229}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Biology\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 14282}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Costume and Textiles\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"fashion\", \"precision\": \"estimate\", \"record_count\": 15468}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Geology\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"geology\", \"precision\": \"estimate\", \"record_count\": 34048}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Military History\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 6838}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Photographs\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"record_count\": 5902}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Social History\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"record_count\": 29774}, {\"institution\": \"Victoria & Albert Museum\", \"subcollection\": \"Victoria & Albert Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"exact\", \"record_count\": 1282240}, {\"institution\": \"Museum of the Home\", \"subcollection\": \"Museum of the Home\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"exact\", \"record_count\": 12200}, {\"institution\": \"Horniman Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 132612}, {\"institution\": \"Imperial War Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 1737698}, {\"institution\": \"National Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 2626}, {\"institution\": \"National Museums Liverpool\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 73682}, {\"institution\": \"National Portrait Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 220000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Entomology collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 34000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Botany collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 6000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Zooology collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 29000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Palaeontology collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 7000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Mineralogy collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 500000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Library and archive collections\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 1500000}, {\"institution\": \"Royal Armouries\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 65627}, {\"institution\": \"Sir John Soane's Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 57164}, {\"institution\": \"Tate Gallery Group\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 79236}, {\"institution\": \"British Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 2000000}, {\"institution\": \"Oxford University\", \"subcollection\": \"History of Science Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 21011}, {\"institution\": \"Oxford University\", \"subcollection\": \"Bodleian Library\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"national\", \"precision\": \"estimate\", \"record_count\": 8000000}, {\"institution\": \"Manchester Metropolitan Unversity\", \"subcollection\": \"Special Collections\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 28600}, {\"institution\": \"SOAS, University of London\", \"subcollection\": \"Special Collections\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 40337}, {\"institution\": \"University of Reading\", \"subcollection\": \"Library Collection\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 0}, {\"institution\": \"Lambeth Palace Library\", \"subcollection\": \"Sion College Collections\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"theology\", \"precision\": \"estimate\", \"record_count\": 15000}, {\"institution\": \"National Museum of the Royal Navy\", \"subcollection\": \"Library Collection\", \"sector\": \"national\", \"type\": \"library\", \"topic\": \"architecture\", \"precision\": \"estimate\", \"record_count\": 195690}, {\"institution\": \"Royal Air Force Museum\", \"subcollection\": \"Library Collection\", \"sector\": \"national\", \"type\": \"library\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1344}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"William Salt Library\", \"sector\": \"regional\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 139389}, {\"institution\": \"Chatham Historic Dockyard\", \"subcollection\": \"Library Collection\", \"sector\": \"independent\", \"type\": \"library\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1548}, {\"institution\": \"Watts Gallery\", \"subcollection\": \"Library Collection\", \"sector\": \"regional\", \"type\": \"library\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 7756}, {\"institution\": \"Victoria & Albert Museum\", \"subcollection\": \"National Art Library\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 849000}, {\"institution\": \"Museum of the Home\", \"subcollection\": \"Library Collection\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"history\", \"precision\": \"exact\", \"record_count\": 6290}, {\"institution\": \"Royal Armouries\", \"subcollection\": \"Library Collection\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 65627}, {\"institution\": \"Sir John Soane's Museum\", \"subcollection\": \"Library Collection\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 57164}, {\"institution\": \"University of Cambridge\", \"subcollection\": \"Whipple Museum of the History of Science\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 6979}, {\"institution\": \"Unversity of Warwick\", \"subcollection\": \"Modern Records Centre\", \"sector\": \"university\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"exact\", \"record_count\": 367655}, {\"institution\": \"University of Reading\", \"subcollection\": \"Archive Collection\", \"sector\": \"university\", \"type\": \"archive\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 186216}, {\"institution\": \"National Waterways Museum\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 53195}, {\"institution\": \"Historic England Archive\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Historic Environment\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Royal Air Force Museum\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 88}, {\"institution\": \"Gwynedd Archive Services\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 12000}, {\"institution\": \"Hampshire Archives and Local Studies\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Kresen Kernow\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 614909}, {\"institution\": \"North East Wales Archives\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 338969}, {\"institution\": \"Public Record Office Northern Ireland\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Stoke on Trent City Archives\", \"sector\": \"regional\", \"type\": \"archives\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 44238}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Staffordshire Record Office\", \"sector\": \"regional\", \"type\": \"archives\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 443779}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Stoke on Trent City Archives\", \"sector\": \"regional\", \"type\": \"archives\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 15606}, {\"institution\": \"Tyne & Wear Archives Catalogue\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 4602160}, {\"institution\": \"West Glamorgan Archive Service\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 230000}, {\"institution\": \"Yorkshire Film Archive\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 8483}, {\"institution\": \"Chatham Historic Dockyard\", \"subcollection\": \"Archive Collection\", \"sector\": \"independent\", \"type\": \"archive\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 2058}, {\"institution\": \"Watts Gallery\", \"subcollection\": \"Archive Collection\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 668}, {\"institution\": \"Aberdeen Archives, Gallery and Museums\", \"subcollection\": \"Archive Collection\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"record_count\": 95798}, {\"institution\": \"Bradford District Museums & Galleries\", \"subcollection\": \"Photographic Archive\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 21878}, {\"institution\": \"Ripon Museums\", \"subcollection\": \"Archive Collection\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 5}, {\"institution\": \"St Helens Borough Council\", \"subcollection\": \"Archive Collections\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 93344}, {\"institution\": \"Victoria & Albert Museum\", \"subcollection\": \"Victoria & Albert Museum Archives\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"art\", \"precision\": \"exact\", \"record_count\": 157835}, {\"institution\": \"Royal Armouries\", \"subcollection\": \"Archive Collection\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 130130}, {\"institution\": \"Sir John Soane's Museum\", \"subcollection\": \"Archive Collection\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 0}, {\"institution\": \"Tate Gallery Group\", \"subcollection\": \"Archive Collection\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 807060}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 10,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "import altair as alt\n",
    "\n",
    "title = alt.TitleParams('Collection Size (Artefact Records) by precision', anchor='middle')\n",
    "alt.Chart(records_data, title=title).mark_bar().encode(\n",
    "    column='precision:O',\n",
    "    x='record_count:Q',\n",
    "    y='topic:N',\n",
    "    tooltip=['subcollection', 'record_count'],\n",
    "    color=alt.Color('institution:N', sort='descending').legend(orient=\"bottom\", titleOrient=\"left\", columns=4)\n",
    ").properties(width=220).resolve_scale(x='independent').configure(numberFormat='.2s')"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "9ca7237c-261a-421f-ae28-67976bddb11a",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "## Artefacts records by topic and precision"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "id": "0e269aa4-ae62-45a6-9123-41299472bbb4",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<style>\n",
       "  #altair-viz-c698e14b6dca447ba724dfd947553726.vega-embed {\n",
       "    width: 100%;\n",
       "    display: flex;\n",
       "  }\n",
       "\n",
       "  #altair-viz-c698e14b6dca447ba724dfd947553726.vega-embed details,\n",
       "  #altair-viz-c698e14b6dca447ba724dfd947553726.vega-embed details summary {\n",
       "    position: relative;\n",
       "  }\n",
       "</style>\n",
       "<div id=\"altair-viz-c698e14b6dca447ba724dfd947553726\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-c698e14b6dca447ba724dfd947553726\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-c698e14b6dca447ba724dfd947553726\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.17.0?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"5.17.0\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"numberFormat\": \".2s\"}, \"data\": {\"name\": \"data-3987631339d2964d44bdb7d1f64babb2\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"field\": \"institution\", \"legend\": {\"orient\": \"bottom\", \"titleOrient\": \"left\", \"columns\": 4}, \"sort\": \"descending\", \"type\": \"nominal\"}, \"column\": {\"field\": \"precision\", \"type\": \"ordinal\"}, \"tooltip\": {\"field\": \"subcollection\", \"type\": \"nominal\"}, \"x\": {\"field\": \"record_count\", \"type\": \"quantitative\"}, \"y\": {\"field\": \"topic\", \"type\": \"nominal\"}}, \"resolve\": {\"scale\": {\"x\": \"independent\"}}, \"title\": {\"text\": \"Collection Size (Artefact Records) by precision\", \"anchor\": \"middle\"}, \"width\": 220, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.17.0.json\", \"datasets\": {\"data-3987631339d2964d44bdb7d1f64babb2\": [{\"institution\": \"Oxford University\", \"subcollection\": \"History of Science Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 33592}, {\"institution\": \"Oxford University\", \"subcollection\": \"Museum of Natural History\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 505745}, {\"institution\": \"Oxford University\", \"subcollection\": \"Pitt Rivers Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"anthopology\", \"precision\": \"estimate\", \"record_count\": 513107}, {\"institution\": \"University of Cambridge\", \"subcollection\": \"Whipple Museum of the History of Science\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 7148}, {\"institution\": \"Durham University\", \"subcollection\": \"Oriental Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 33234}, {\"institution\": \"University College London\", \"subcollection\": \"Petrie Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 83455}, {\"institution\": \"University College London\", \"subcollection\": \"UCL Art Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 10712}, {\"institution\": \"University College London\", \"subcollection\": \"UCL Pathology Collection\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"record_count\": 8817}, {\"institution\": \"University College London\", \"subcollection\": \"UCL Pathology Collection\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 1462}, {\"institution\": \"Glasgow Woman's Library\", \"subcollection\": \"Museum Collections\", \"sector\": \"library\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 3567}, {\"institution\": \"National Museum of the Royal Navy\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"architecture\", \"precision\": \"estimate\", \"record_count\": 195690}, {\"institution\": \"National Museums Scotland\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"architecture\", \"precision\": \"estimate\", \"record_count\": 820000}, {\"institution\": \"National Waterways Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 4574}, {\"institution\": \"Government Art Collection\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 15247}, {\"institution\": \"People's History Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 5680}, {\"institution\": \"Portable Antiquities Scheme\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1133397}, {\"institution\": \"Royal Air Force Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1344}, {\"institution\": \"Royal Botanic Gardens Kew\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 5700000}, {\"institution\": \"Royal Collection\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 289595}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 57017}, {\"institution\": \"Courtauld Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 33501}, {\"institution\": \"Dulwich Picture Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 33501}, {\"institution\": \"Chatham Historic Dockyard\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1548}, {\"institution\": \"Colchester and Ipswich Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 220000}, {\"institution\": \"London Transport Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 271610}, {\"institution\": \"Food Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 32040}, {\"institution\": \"Watts Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 7756}, {\"institution\": \"Aberdeen Archives, Gallery and Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"record_count\": 151529}, {\"institution\": \"Black Country Living Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"record_count\": 4903}, {\"institution\": \"The Box Plymouth\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"record_count\": 21691}, {\"institution\": \"Colchester and Ipswich Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 220000}, {\"institution\": \"Dundee Heritage Trust\", \"subcollection\": \"Martime\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"record_count\": 2411}, {\"institution\": \"Dundee Heritage Trust\", \"subcollection\": \"Textiles\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"fashion\", \"precision\": \"estimate\", \"record_count\": 5864}, {\"institution\": \"Dundee Heritage Trust\", \"subcollection\": \"Dundee and Social History\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"record_count\": 317}, {\"institution\": \"Poole Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1489}, {\"institution\": \"Potteries Museum and Art Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1489}, {\"institution\": \"Ripon Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 15}, {\"institution\": \"Royal Albert Memorial Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 16000}, {\"institution\": \"Sheffield Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1000}, {\"institution\": \"Tyne & Wear Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 490107}, {\"institution\": \"Wiltshire Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 126410}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Fine Art\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 15733}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Decorative Arts\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 11080}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Archaeology\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"archaeology\", \"precision\": \"estimate\", \"record_count\": 21229}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Biology\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 14282}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Costume and Textiles\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"fashion\", \"precision\": \"estimate\", \"record_count\": 15468}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Geology\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"geology\", \"precision\": \"estimate\", \"record_count\": 34048}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Military History\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 6838}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Photographs\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"record_count\": 5902}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Social History\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"record_count\": 29774}, {\"institution\": \"Victoria & Albert Museum\", \"subcollection\": \"Victoria & Albert Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"exact\", \"record_count\": 1282171}, {\"institution\": \"Museum of the Home\", \"subcollection\": \"Museum of the Home\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"exact\", \"record_count\": 12200}, {\"institution\": \"Horniman Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 132612}, {\"institution\": \"Imperial War Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 1737698}, {\"institution\": \"National Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 2626}, {\"institution\": \"National Museums Liverpool\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 73682}, {\"institution\": \"National Portrait Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 220000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Entomology collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 34000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Botany collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 6000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Zooology collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 29000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Palaeontology collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 7000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Mineralogy collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 500000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Library and archive collections\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 1500000}, {\"institution\": \"Royal Armouries\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 65627}, {\"institution\": \"Sir John Soane's Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 57164}, {\"institution\": \"Tate Gallery Group\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 79236}, {\"institution\": \"British Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 2000000}, {\"institution\": \"Oxford University\", \"subcollection\": \"History of Science Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 21011}, {\"institution\": \"Oxford University\", \"subcollection\": \"Bodleian Library\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"national\", \"precision\": \"estimate\", \"record_count\": 8000000}, {\"institution\": \"Manchester Metropolitan Unversity\", \"subcollection\": \"Special Collections\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 28600}, {\"institution\": \"SOAS, University of London\", \"subcollection\": \"Special Collections\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 40337}, {\"institution\": \"University of Reading\", \"subcollection\": \"Library Collection\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 0}, {\"institution\": \"Lambeth Palace Library\", \"subcollection\": \"Sion College Collections\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"theology\", \"precision\": \"estimate\", \"record_count\": 15000}, {\"institution\": \"National Museum of the Royal Navy\", \"subcollection\": \"Library Collection\", \"sector\": \"national\", \"type\": \"library\", \"topic\": \"architecture\", \"precision\": \"estimate\", \"record_count\": 195690}, {\"institution\": \"Royal Air Force Museum\", \"subcollection\": \"Library Collection\", \"sector\": \"national\", \"type\": \"library\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1344}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"William Salt Library\", \"sector\": \"regional\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 139389}, {\"institution\": \"Chatham Historic Dockyard\", \"subcollection\": \"Library Collection\", \"sector\": \"independent\", \"type\": \"library\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1548}, {\"institution\": \"Watts Gallery\", \"subcollection\": \"Library Collection\", \"sector\": \"regional\", \"type\": \"library\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 7756}, {\"institution\": \"Victoria & Albert Museum\", \"subcollection\": \"National Art Library\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 849000}, {\"institution\": \"Museum of the Home\", \"subcollection\": \"Library Collection\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"history\", \"precision\": \"exact\", \"record_count\": 6290}, {\"institution\": \"Royal Armouries\", \"subcollection\": \"Library Collection\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 65627}, {\"institution\": \"Sir John Soane's Museum\", \"subcollection\": \"Library Collection\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 57164}, {\"institution\": \"University of Cambridge\", \"subcollection\": \"Whipple Museum of the History of Science\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 6979}, {\"institution\": \"Unversity of Warwick\", \"subcollection\": \"Modern Records Centre\", \"sector\": \"university\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"exact\", \"record_count\": 367655}, {\"institution\": \"University of Reading\", \"subcollection\": \"Archive Collection\", \"sector\": \"university\", \"type\": \"archive\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 186216}, {\"institution\": \"National Waterways Museum\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 53195}, {\"institution\": \"Historic England Archive\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Historic Environment\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Royal Air Force Museum\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 88}, {\"institution\": \"Gwynedd Archive Services\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 12000}, {\"institution\": \"Hampshire Archives and Local Studies\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Kresen Kernow\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 614909}, {\"institution\": \"North East Wales Archives\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 338969}, {\"institution\": \"Public Record Office Northern Ireland\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Stoke on Trent City Archives\", \"sector\": \"regional\", \"type\": \"archives\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 44238}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Staffordshire Record Office\", \"sector\": \"regional\", \"type\": \"archives\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 443779}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Stoke on Trent City Archives\", \"sector\": \"regional\", \"type\": \"archives\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 15606}, {\"institution\": \"Tyne & Wear Archives Catalogue\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 4602160}, {\"institution\": \"West Glamorgan Archive Service\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 230000}, {\"institution\": \"Yorkshire Film Archive\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 8483}, {\"institution\": \"Chatham Historic Dockyard\", \"subcollection\": \"Archive Collection\", \"sector\": \"independent\", \"type\": \"archive\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 2058}, {\"institution\": \"Watts Gallery\", \"subcollection\": \"Archive Collection\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 668}, {\"institution\": \"Aberdeen Archives, Gallery and Museums\", \"subcollection\": \"Archive Collection\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"record_count\": 95798}, {\"institution\": \"Bradford District Museums & Galleries\", \"subcollection\": \"Photographic Archive\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 21878}, {\"institution\": \"Ripon Museums\", \"subcollection\": \"Archive Collection\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 5}, {\"institution\": \"St Helens Borough Council\", \"subcollection\": \"Archive Collections\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 93344}, {\"institution\": \"Victoria & Albert Museum\", \"subcollection\": \"Victoria & Albert Museum Archives\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"art\", \"precision\": \"exact\", \"record_count\": 157835}, {\"institution\": \"Royal Armouries\", \"subcollection\": \"Archive Collection\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 130130}, {\"institution\": \"Sir John Soane's Museum\", \"subcollection\": \"Archive Collection\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 0}, {\"institution\": \"Tate Gallery Group\", \"subcollection\": \"Archive Collection\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 807060}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 4,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "title = alt.TitleParams('Collection Size (Artefact Records) by precision', anchor='middle')\n",
    "alt.Chart(records_data, title=title).mark_bar().encode(\n",
    "    column='precision:O',\n",
    "    x='record_count:Q',\n",
    "    y='topic:N',\n",
    "    tooltip=['subcollection', 'record_count'],\n",
    "    color=alt.Color('institution:N', sort='descending').legend(orient=\"bottom\", titleOrient=\"left\", columns=4)\n",
    ").properties(width=220).resolve_scale(x='independent').configure(numberFormat='.2s')"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "264467d9-10ba-40fe-9780-66cd88862ad4",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "## Artefact records with subcollections size and precision"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "id": "02993910-d83c-4a22-96ac-404d5091ad27",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<style>\n",
       "  #altair-viz-a0cef0cfcf8c49129b928d5b487acaa7.vega-embed {\n",
       "    width: 100%;\n",
       "    display: flex;\n",
       "  }\n",
       "\n",
       "  #altair-viz-a0cef0cfcf8c49129b928d5b487acaa7.vega-embed details,\n",
       "  #altair-viz-a0cef0cfcf8c49129b928d5b487acaa7.vega-embed details summary {\n",
       "    position: relative;\n",
       "  }\n",
       "</style>\n",
       "<div id=\"altair-viz-a0cef0cfcf8c49129b928d5b487acaa7\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-a0cef0cfcf8c49129b928d5b487acaa7\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-a0cef0cfcf8c49129b928d5b487acaa7\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.17.0?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"5.17.0\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"numberFormat\": \".2s\"}, \"data\": {\"name\": \"data-3987631339d2964d44bdb7d1f64babb2\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"field\": \"subcollection\", \"legend\": {\"orient\": \"bottom\", \"columns\": 4, \"titleOrient\": \"left\"}, \"type\": \"nominal\"}, \"column\": {\"field\": \"precision\", \"type\": \"ordinal\"}, \"tooltip\": [{\"field\": \"institution\", \"type\": \"nominal\"}, {\"field\": \"subcollection\", \"type\": \"nominal\"}, {\"field\": \"record_count\", \"type\": \"quantitative\"}], \"x\": {\"field\": \"record_count\", \"type\": \"quantitative\"}, \"y\": {\"field\": \"institution\", \"type\": \"nominal\"}}, \"resolve\": {\"scale\": {\"x\": \"independent\"}}, \"title\": {\"text\": \"Records per institution by named sub-collections\", \"anchor\": \"middle\"}, \"width\": 250, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.17.0.json\", \"datasets\": {\"data-3987631339d2964d44bdb7d1f64babb2\": [{\"institution\": \"Oxford University\", \"subcollection\": \"History of Science Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 33592}, {\"institution\": \"Oxford University\", \"subcollection\": \"Museum of Natural History\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 505745}, {\"institution\": \"Oxford University\", \"subcollection\": \"Pitt Rivers Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"anthopology\", \"precision\": \"estimate\", \"record_count\": 513107}, {\"institution\": \"University of Cambridge\", \"subcollection\": \"Whipple Museum of the History of Science\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 7148}, {\"institution\": \"Durham University\", \"subcollection\": \"Oriental Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 33234}, {\"institution\": \"University College London\", \"subcollection\": \"Petrie Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 83455}, {\"institution\": \"University College London\", \"subcollection\": \"UCL Art Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 10712}, {\"institution\": \"University College London\", \"subcollection\": \"UCL Pathology Collection\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"record_count\": 8817}, {\"institution\": \"University College London\", \"subcollection\": \"UCL Pathology Collection\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 1462}, {\"institution\": \"Glasgow Woman's Library\", \"subcollection\": \"Museum Collections\", \"sector\": \"library\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 3567}, {\"institution\": \"National Museum of the Royal Navy\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"architecture\", \"precision\": \"estimate\", \"record_count\": 195690}, {\"institution\": \"National Museums Scotland\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"architecture\", \"precision\": \"estimate\", \"record_count\": 820000}, {\"institution\": \"National Waterways Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 4574}, {\"institution\": \"Government Art Collection\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 15247}, {\"institution\": \"People's History Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 5680}, {\"institution\": \"Portable Antiquities Scheme\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1133397}, {\"institution\": \"Royal Air Force Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1344}, {\"institution\": \"Royal Botanic Gardens Kew\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 5700000}, {\"institution\": \"Royal Collection\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 289595}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 57017}, {\"institution\": \"Courtauld Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 33501}, {\"institution\": \"Dulwich Picture Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 33501}, {\"institution\": \"Chatham Historic Dockyard\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1548}, {\"institution\": \"Colchester and Ipswich Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 220000}, {\"institution\": \"London Transport Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 271610}, {\"institution\": \"Food Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 32040}, {\"institution\": \"Watts Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 7756}, {\"institution\": \"Aberdeen Archives, Gallery and Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"record_count\": 151529}, {\"institution\": \"Black Country Living Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"record_count\": 4903}, {\"institution\": \"The Box Plymouth\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"record_count\": 21691}, {\"institution\": \"Colchester and Ipswich Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 220000}, {\"institution\": \"Dundee Heritage Trust\", \"subcollection\": \"Martime\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"record_count\": 2411}, {\"institution\": \"Dundee Heritage Trust\", \"subcollection\": \"Textiles\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"fashion\", \"precision\": \"estimate\", \"record_count\": 5864}, {\"institution\": \"Dundee Heritage Trust\", \"subcollection\": \"Dundee and Social History\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"record_count\": 317}, {\"institution\": \"Poole Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1489}, {\"institution\": \"Potteries Museum and Art Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1489}, {\"institution\": \"Ripon Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 15}, {\"institution\": \"Royal Albert Memorial Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 16000}, {\"institution\": \"Sheffield Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1000}, {\"institution\": \"Tyne & Wear Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 490107}, {\"institution\": \"Wiltshire Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 126410}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Fine Art\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 15733}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Decorative Arts\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 11080}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Archaeology\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"archaeology\", \"precision\": \"estimate\", \"record_count\": 21229}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Biology\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 14282}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Costume and Textiles\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"fashion\", \"precision\": \"estimate\", \"record_count\": 15468}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Geology\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"geology\", \"precision\": \"estimate\", \"record_count\": 34048}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Military History\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 6838}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Photographs\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"record_count\": 5902}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Social History\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"record_count\": 29774}, {\"institution\": \"Victoria & Albert Museum\", \"subcollection\": \"Victoria & Albert Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"exact\", \"record_count\": 1282171}, {\"institution\": \"Museum of the Home\", \"subcollection\": \"Museum of the Home\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"exact\", \"record_count\": 12200}, {\"institution\": \"Horniman Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 132612}, {\"institution\": \"Imperial War Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 1737698}, {\"institution\": \"National Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 2626}, {\"institution\": \"National Museums Liverpool\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 73682}, {\"institution\": \"National Portrait Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 220000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Entomology collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 34000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Botany collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 6000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Zooology collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 29000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Palaeontology collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 7000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Mineralogy collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 500000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Library and archive collections\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 1500000}, {\"institution\": \"Royal Armouries\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 65627}, {\"institution\": \"Sir John Soane's Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 57164}, {\"institution\": \"Tate Gallery Group\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 79236}, {\"institution\": \"British Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 2000000}, {\"institution\": \"Oxford University\", \"subcollection\": \"History of Science Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 21011}, {\"institution\": \"Oxford University\", \"subcollection\": \"Bodleian Library\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"national\", \"precision\": \"estimate\", \"record_count\": 8000000}, {\"institution\": \"Manchester Metropolitan Unversity\", \"subcollection\": \"Special Collections\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 28600}, {\"institution\": \"SOAS, University of London\", \"subcollection\": \"Special Collections\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 40337}, {\"institution\": \"University of Reading\", \"subcollection\": \"Library Collection\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 0}, {\"institution\": \"Lambeth Palace Library\", \"subcollection\": \"Sion College Collections\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"theology\", \"precision\": \"estimate\", \"record_count\": 15000}, {\"institution\": \"National Museum of the Royal Navy\", \"subcollection\": \"Library Collection\", \"sector\": \"national\", \"type\": \"library\", \"topic\": \"architecture\", \"precision\": \"estimate\", \"record_count\": 195690}, {\"institution\": \"Royal Air Force Museum\", \"subcollection\": \"Library Collection\", \"sector\": \"national\", \"type\": \"library\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1344}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"William Salt Library\", \"sector\": \"regional\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 139389}, {\"institution\": \"Chatham Historic Dockyard\", \"subcollection\": \"Library Collection\", \"sector\": \"independent\", \"type\": \"library\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1548}, {\"institution\": \"Watts Gallery\", \"subcollection\": \"Library Collection\", \"sector\": \"regional\", \"type\": \"library\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 7756}, {\"institution\": \"Victoria & Albert Museum\", \"subcollection\": \"National Art Library\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 849000}, {\"institution\": \"Museum of the Home\", \"subcollection\": \"Library Collection\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"history\", \"precision\": \"exact\", \"record_count\": 6290}, {\"institution\": \"Royal Armouries\", \"subcollection\": \"Library Collection\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 65627}, {\"institution\": \"Sir John Soane's Museum\", \"subcollection\": \"Library Collection\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 57164}, {\"institution\": \"University of Cambridge\", \"subcollection\": \"Whipple Museum of the History of Science\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 6979}, {\"institution\": \"Unversity of Warwick\", \"subcollection\": \"Modern Records Centre\", \"sector\": \"university\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"exact\", \"record_count\": 367655}, {\"institution\": \"University of Reading\", \"subcollection\": \"Archive Collection\", \"sector\": \"university\", \"type\": \"archive\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 186216}, {\"institution\": \"National Waterways Museum\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 53195}, {\"institution\": \"Historic England Archive\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Historic Environment\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Royal Air Force Museum\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 88}, {\"institution\": \"Gwynedd Archive Services\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 12000}, {\"institution\": \"Hampshire Archives and Local Studies\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Kresen Kernow\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 614909}, {\"institution\": \"North East Wales Archives\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 338969}, {\"institution\": \"Public Record Office Northern Ireland\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Stoke on Trent City Archives\", \"sector\": \"regional\", \"type\": \"archives\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 44238}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Staffordshire Record Office\", \"sector\": \"regional\", \"type\": \"archives\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 443779}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Stoke on Trent City Archives\", \"sector\": \"regional\", \"type\": \"archives\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 15606}, {\"institution\": \"Tyne & Wear Archives Catalogue\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 4602160}, {\"institution\": \"West Glamorgan Archive Service\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 230000}, {\"institution\": \"Yorkshire Film Archive\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 8483}, {\"institution\": \"Chatham Historic Dockyard\", \"subcollection\": \"Archive Collection\", \"sector\": \"independent\", \"type\": \"archive\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 2058}, {\"institution\": \"Watts Gallery\", \"subcollection\": \"Archive Collection\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 668}, {\"institution\": \"Aberdeen Archives, Gallery and Museums\", \"subcollection\": \"Archive Collection\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"record_count\": 95798}, {\"institution\": \"Bradford District Museums & Galleries\", \"subcollection\": \"Photographic Archive\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 21878}, {\"institution\": \"Ripon Museums\", \"subcollection\": \"Archive Collection\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 5}, {\"institution\": \"St Helens Borough Council\", \"subcollection\": \"Archive Collections\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 93344}, {\"institution\": \"Victoria & Albert Museum\", \"subcollection\": \"Victoria & Albert Museum Archives\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"art\", \"precision\": \"exact\", \"record_count\": 157835}, {\"institution\": \"Royal Armouries\", \"subcollection\": \"Archive Collection\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 130130}, {\"institution\": \"Sir John Soane's Museum\", \"subcollection\": \"Archive Collection\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 0}, {\"institution\": \"Tate Gallery Group\", \"subcollection\": \"Archive Collection\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 807060}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 6,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "import altair as alt\n",
    "\n",
    "title = alt.TitleParams('Records per institution by named sub-collections', anchor='middle')\n",
    "alt.Chart(records_data, title=title).mark_bar().encode(\n",
    "        alt.Color('subcollection:N').legend(orient=\"bottom\", columns=4, titleOrient=\"left\"),\n",
    "    column='precision:O',\n",
    "    tooltip=['institution', 'subcollection', 'record_count'],\n",
    "    x='record_count:Q',\n",
    "    y='institution:N'\n",
    ").properties(width=250).resolve_scale(x='independent').configure(numberFormat='.2s')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "id": "d99d62a0-d170-4cbf-b0a5-3d5264409f76",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-cell"
    ]
   },
   "outputs": [],
   "source": [
    "# I really like this but it doesn't make sense as a table view. Can't think how to make it work\n",
    "#alt.Chart(records_data, width=60, height=alt.Step(8)).mark_bar().encode(\n",
    "#    alt.X(\"record_count:Q\"),\n",
    "#    alt.Y(\"type:N\"),\n",
    "#    alt.Color(\"type:N\").title(\"settings\").legend(orient=\"bottom\", titleOrient=\"left\"),\n",
    "#    alt.Row(\"institution:N\").title(\"Institution\").header(labelAngle=0, labelAlign='left' ),\n",
    "#    alt.Column(\"subcollection:N\").title(\"Sub Collection\"),\n",
    "#).configure(numberFormat='.2s').configure(numberFormat='.2s')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "id": "f3d67ee1-989d-4883-8137-715e6c40f660",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<style>\n",
       "  #altair-viz-c698e14b6dca447ba724dfd947553726.vega-embed {\n",
       "    width: 100%;\n",
       "    display: flex;\n",
       "  }\n",
       "\n",
       "  #altair-viz-c698e14b6dca447ba724dfd947553726.vega-embed details,\n",
       "  #altair-viz-c698e14b6dca447ba724dfd947553726.vega-embed details summary {\n",
       "    position: relative;\n",
       "  }\n",
       "</style>\n",
       "<div id=\"altair-viz-c698e14b6dca447ba724dfd947553726\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-c698e14b6dca447ba724dfd947553726\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-c698e14b6dca447ba724dfd947553726\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.17.0?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"5.17.0\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"numberFormat\": \".2s\"}, \"data\": {\"name\": \"data-3987631339d2964d44bdb7d1f64babb2\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"field\": \"institution\", \"legend\": {\"orient\": \"bottom\", \"titleOrient\": \"left\", \"columns\": 4}, \"sort\": \"descending\", \"type\": \"nominal\"}, \"column\": {\"field\": \"precision\", \"type\": \"ordinal\"}, \"tooltip\": {\"field\": \"subcollection\", \"type\": \"nominal\"}, \"x\": {\"field\": \"record_count\", \"type\": \"quantitative\"}, \"y\": {\"field\": \"topic\", \"type\": \"nominal\"}}, \"resolve\": {\"scale\": {\"x\": \"independent\"}}, \"title\": {\"text\": \"Collection Size (Artefact Records) by precision\", \"anchor\": \"middle\"}, \"width\": 220, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.17.0.json\", \"datasets\": {\"data-3987631339d2964d44bdb7d1f64babb2\": [{\"institution\": \"Oxford University\", \"subcollection\": \"History of Science Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 33592}, {\"institution\": \"Oxford University\", \"subcollection\": \"Museum of Natural History\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 505745}, {\"institution\": \"Oxford University\", \"subcollection\": \"Pitt Rivers Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"anthopology\", \"precision\": \"estimate\", \"record_count\": 513107}, {\"institution\": \"University of Cambridge\", \"subcollection\": \"Whipple Museum of the History of Science\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 7148}, {\"institution\": \"Durham University\", \"subcollection\": \"Oriental Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 33234}, {\"institution\": \"University College London\", \"subcollection\": \"Petrie Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 83455}, {\"institution\": \"University College London\", \"subcollection\": \"UCL Art Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 10712}, {\"institution\": \"University College London\", \"subcollection\": \"UCL Pathology Collection\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"record_count\": 8817}, {\"institution\": \"University College London\", \"subcollection\": \"UCL Pathology Collection\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 1462}, {\"institution\": \"Glasgow Woman's Library\", \"subcollection\": \"Museum Collections\", \"sector\": \"library\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 3567}, {\"institution\": \"National Museum of the Royal Navy\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"architecture\", \"precision\": \"estimate\", \"record_count\": 195690}, {\"institution\": \"National Museums Scotland\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"architecture\", \"precision\": \"estimate\", \"record_count\": 820000}, {\"institution\": \"National Waterways Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 4574}, {\"institution\": \"Government Art Collection\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 15247}, {\"institution\": \"People's History Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 5680}, {\"institution\": \"Portable Antiquities Scheme\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1133397}, {\"institution\": \"Royal Air Force Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1344}, {\"institution\": \"Royal Botanic Gardens Kew\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 5700000}, {\"institution\": \"Royal Collection\", \"subcollection\": \"Museum Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 289595}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 57017}, {\"institution\": \"Courtauld Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 33501}, {\"institution\": \"Dulwich Picture Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 33501}, {\"institution\": \"Chatham Historic Dockyard\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1548}, {\"institution\": \"Colchester and Ipswich Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 220000}, {\"institution\": \"London Transport Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 271610}, {\"institution\": \"Food Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 32040}, {\"institution\": \"Watts Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 7756}, {\"institution\": \"Aberdeen Archives, Gallery and Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"record_count\": 151529}, {\"institution\": \"Black Country Living Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"record_count\": 4903}, {\"institution\": \"The Box Plymouth\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"record_count\": 21691}, {\"institution\": \"Colchester and Ipswich Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 220000}, {\"institution\": \"Dundee Heritage Trust\", \"subcollection\": \"Martime\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"record_count\": 2411}, {\"institution\": \"Dundee Heritage Trust\", \"subcollection\": \"Textiles\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"fashion\", \"precision\": \"estimate\", \"record_count\": 5864}, {\"institution\": \"Dundee Heritage Trust\", \"subcollection\": \"Dundee and Social History\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"record_count\": 317}, {\"institution\": \"Poole Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1489}, {\"institution\": \"Potteries Museum and Art Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1489}, {\"institution\": \"Ripon Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 15}, {\"institution\": \"Royal Albert Memorial Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 16000}, {\"institution\": \"Sheffield Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1000}, {\"institution\": \"Tyne & Wear Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 490107}, {\"institution\": \"Wiltshire Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 126410}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Fine Art\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 15733}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Decorative Arts\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 11080}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Archaeology\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"archaeology\", \"precision\": \"estimate\", \"record_count\": 21229}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Biology\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 14282}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Costume and Textiles\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"fashion\", \"precision\": \"estimate\", \"record_count\": 15468}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Geology\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"geology\", \"precision\": \"estimate\", \"record_count\": 34048}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Military History\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 6838}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Photographs\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"record_count\": 5902}, {\"institution\": \"York Museums Trust\", \"subcollection\": \"Social History\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"record_count\": 29774}, {\"institution\": \"Victoria & Albert Museum\", \"subcollection\": \"Victoria & Albert Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"exact\", \"record_count\": 1282171}, {\"institution\": \"Museum of the Home\", \"subcollection\": \"Museum of the Home\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"exact\", \"record_count\": 12200}, {\"institution\": \"Horniman Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 132612}, {\"institution\": \"Imperial War Museums\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 1737698}, {\"institution\": \"National Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 2626}, {\"institution\": \"National Museums Liverpool\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 73682}, {\"institution\": \"National Portrait Gallery\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 220000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Entomology collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 34000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Botany collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 6000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Zooology collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 29000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Palaeontology collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 7000000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Mineralogy collections\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 500000}, {\"institution\": \"Natural History Museum\", \"subcollection\": \"Library and archive collections\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 1500000}, {\"institution\": \"Royal Armouries\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 65627}, {\"institution\": \"Sir John Soane's Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 57164}, {\"institution\": \"Tate Gallery Group\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 79236}, {\"institution\": \"British Museum\", \"subcollection\": \"Museum Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 2000000}, {\"institution\": \"Oxford University\", \"subcollection\": \"History of Science Museum\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 21011}, {\"institution\": \"Oxford University\", \"subcollection\": \"Bodleian Library\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"national\", \"precision\": \"estimate\", \"record_count\": 8000000}, {\"institution\": \"Manchester Metropolitan Unversity\", \"subcollection\": \"Special Collections\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 28600}, {\"institution\": \"SOAS, University of London\", \"subcollection\": \"Special Collections\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 40337}, {\"institution\": \"University of Reading\", \"subcollection\": \"Library Collection\", \"sector\": \"university\", \"type\": \"library\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 0}, {\"institution\": \"Lambeth Palace Library\", \"subcollection\": \"Sion College Collections\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"theology\", \"precision\": \"estimate\", \"record_count\": 15000}, {\"institution\": \"National Museum of the Royal Navy\", \"subcollection\": \"Library Collection\", \"sector\": \"national\", \"type\": \"library\", \"topic\": \"architecture\", \"precision\": \"estimate\", \"record_count\": 195690}, {\"institution\": \"Royal Air Force Museum\", \"subcollection\": \"Library Collection\", \"sector\": \"national\", \"type\": \"library\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1344}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"William Salt Library\", \"sector\": \"regional\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 139389}, {\"institution\": \"Chatham Historic Dockyard\", \"subcollection\": \"Library Collection\", \"sector\": \"independent\", \"type\": \"library\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 1548}, {\"institution\": \"Watts Gallery\", \"subcollection\": \"Library Collection\", \"sector\": \"regional\", \"type\": \"library\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 7756}, {\"institution\": \"Victoria & Albert Museum\", \"subcollection\": \"National Art Library\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 849000}, {\"institution\": \"Museum of the Home\", \"subcollection\": \"Library Collection\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"history\", \"precision\": \"exact\", \"record_count\": 6290}, {\"institution\": \"Royal Armouries\", \"subcollection\": \"Library Collection\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 65627}, {\"institution\": \"Sir John Soane's Museum\", \"subcollection\": \"Library Collection\", \"sector\": \"dcms\", \"type\": \"library\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 57164}, {\"institution\": \"University of Cambridge\", \"subcollection\": \"Whipple Museum of the History of Science\", \"sector\": \"university\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"record_count\": 6979}, {\"institution\": \"Unversity of Warwick\", \"subcollection\": \"Modern Records Centre\", \"sector\": \"university\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"exact\", \"record_count\": 367655}, {\"institution\": \"University of Reading\", \"subcollection\": \"Archive Collection\", \"sector\": \"university\", \"type\": \"archive\", \"topic\": \"history\", \"precision\": \"estimate\", \"record_count\": 186216}, {\"institution\": \"National Waterways Museum\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 53195}, {\"institution\": \"Historic England Archive\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Historic Environment\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Royal Air Force Museum\", \"subcollection\": \"Archive Collection\", \"sector\": \"national\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 88}, {\"institution\": \"Gwynedd Archive Services\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 12000}, {\"institution\": \"Hampshire Archives and Local Studies\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Kresen Kernow\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 614909}, {\"institution\": \"North East Wales Archives\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 338969}, {\"institution\": \"Public Record Office Northern Ireland\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"transport\", \"precision\": \"estimate\", \"record_count\": 1000000}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Stoke on Trent City Archives\", \"sector\": \"regional\", \"type\": \"archives\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 44238}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Staffordshire Record Office\", \"sector\": \"regional\", \"type\": \"archives\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 443779}, {\"institution\": \"Staffordshire Archive and Heritage\", \"subcollection\": \"Stoke on Trent City Archives\", \"sector\": \"regional\", \"type\": \"archives\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 15606}, {\"institution\": \"Tyne & Wear Archives Catalogue\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 4602160}, {\"institution\": \"West Glamorgan Archive Service\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 230000}, {\"institution\": \"Yorkshire Film Archive\", \"subcollection\": \"Archive Collection\", \"sector\": \"archives\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 8483}, {\"institution\": \"Chatham Historic Dockyard\", \"subcollection\": \"Archive Collection\", \"sector\": \"independent\", \"type\": \"archive\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 2058}, {\"institution\": \"Watts Gallery\", \"subcollection\": \"Archive Collection\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"military\", \"precision\": \"estimate\", \"record_count\": 668}, {\"institution\": \"Aberdeen Archives, Gallery and Museums\", \"subcollection\": \"Archive Collection\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"record_count\": 95798}, {\"institution\": \"Bradford District Museums & Galleries\", \"subcollection\": \"Photographic Archive\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 21878}, {\"institution\": \"Ripon Museums\", \"subcollection\": \"Archive Collection\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"art\", \"precision\": \"estimate\", \"record_count\": 5}, {\"institution\": \"St Helens Borough Council\", \"subcollection\": \"Archive Collections\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"record_count\": 93344}, {\"institution\": \"Victoria & Albert Museum\", \"subcollection\": \"Victoria & Albert Museum Archives\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"art\", \"precision\": \"exact\", \"record_count\": 157835}, {\"institution\": \"Royal Armouries\", \"subcollection\": \"Archive Collection\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 130130}, {\"institution\": \"Sir John Soane's Museum\", \"subcollection\": \"Archive Collection\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 0}, {\"institution\": \"Tate Gallery Group\", \"subcollection\": \"Archive Collection\", \"sector\": \"dcms\", \"type\": \"archive\", \"topic\": \"nature\", \"precision\": \"estimate\", \"record_count\": 807060}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 4,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "title = alt.TitleParams('Collection Size (Artefact Records) by precision', anchor='middle')\n",
    "alt.Chart(records_data, title=title).mark_bar().encode(\n",
    "    column='precision:O',\n",
    "    x='record_count:Q',\n",
    "    y='topic:N',\n",
    "    tooltip=['subcollection', 'record_count'],\n",
    "    color=alt.Color('institution:N', sort='descending').legend(orient=\"bottom\", titleOrient=\"left\", columns=4)\n",
    ").properties(width=220).resolve_scale(x='independent').configure(numberFormat='.2s')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "06f886a5-2967-4b4a-ba82-3c39d3c195e4",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.9.18"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
